import { ethers } from 'ethers';

export const TESTNET_RPC = 'http://blockchain.enface.io:59321';
// export const TESTNET_RPC = 'http://192.168.1.79:59321';

export const PREFIX_RSA_PUE = ':publicEnc';
export const PREFIX_RSA_PUS = ':publicSign';
export const RSA_KEYS_BITS = 2048;
export const CONTRACT_TESTNET = '0x2900ecb89089ff273c7ffE29C26A1158cEDF24a4';
export const CONTRACT_ROPSTEN = '0x9ba728e084b9e7785df90c2a4f2fea5cff00896a';
export const CONTRACT_HOMESTEAD = '0x40130c051dd4e26922b84ac7d812d3dee7310ba7';

export const {
  ETH_WALLET_MNEMONIC,
  ROOT_WALLET_MNEMONIC,
} = process.env;
export const ID_MAINNET = 1;
export const ID_TESTNET = 13579;

export const faucetCodes = {
  FAUCET_SUCCESS: 0,
  FAUCET_BAD_REQUEST: 1,
  FAUCET_DUPLICATE_REQUEST: 2,
  FAUCET_EXCEPTION: 3,
  FAUCET_BALANCE_HIGH: 4,
  FAUCET_BAD_CODE: 5,
};

export const promo = {
  PROMO_CODE: 'U996F4HTQN764D0P',
  PROMO_CODE_50: 'U882F4HTQN712D0P',
  CONTRACT_CURRENCY: {
    usd: '0x9208A089C4A83E464F36791BBBa5a21725C394f2',
    eur: '0xDF02e2849d67E681A0F0cf6A1498F4ACfB777b3C',
    rub: '0x1E0690cE241e9106044f3EC241dD894cc2F22c86',
  },
};

export const TYPE_AIRDROP = 0;
export const TYPE_PROMO = 1;

export const MAX_DEVICE_ID_LENGTH = 100;
export const MIN_BALANCE_TO_AIRDROP = ethers.utils.parseEther('1.1');
export const MIN_BALANCE_TO_FILL_SERVER_WALLET = ethers.utils.parseEther('10');

export const CONTRACTS = {
  items: [
    {
      id: 'usd',
      title: 'USD',
      contractAddress: '0x9208A089C4A83E464F36791BBBa5a21725C394f2',
    },
    {
      id: 'eur',
      title: 'EURO',
      contractAddress: '0xDF02e2849d67E681A0F0cf6A1498F4ACfB777b3C',
    },
    {
      id: 'rub',
      title: 'RUB',
      contractAddress: '0x1E0690cE241e9106044f3EC241dD894cc2F22c86',
    },
  ],
};

export const KEY_ROLES = {
  'ENC': {
    ext: true,
    use: [
      'encrypt',
      'decrypt',
    ],
    alg: {
      'name': 'RSA-OAEP',
      'hash': 'SHA-1',
      'modulusLength': 2048,
      'publicExponent': new Uint8Array([1, 0, 1]),
    },
    toString: () => { return 'ENC'; },
  },
  'SIGN': {
    ext: true,
    use: [
      'verify',
      'sign',
    ],
    alg: {
      'name': 'RSASSA-PKCS1-v1_5',
      'hash': 'SHA-256',
      'modulusLength': 2048,
      'publicExponent': new Uint8Array([1, 0, 1]),
    },
    toString: () => { return 'SIGN'; },
  },
};
