import { ethers } from 'ethers';
import * as bc from './constants';
import { wallet, rootWallet, createContractCurrency } from './index';
import Models from '../models';

const checkAddress = value => {
  try {
    return ethers.utils.getAddress(value);
  } catch (e) {
    return false;
  }
};

// add ethers to server's wallet
// airdrop( '0x54b83e8D0d85bF430b3bf135F3ea1a1487f81335', ethers.utils.parseEther( '100' ) );

export const airdropCrypto = async post => {
  console.log('[airdropCrypto]', post);
  const result = {
    code: bc.faucetCodes.FAUCET_SUCCESS,
  };
  if (
    !post.address
    || !post.deviceId
    || !post.deviceId.trim()
    || !checkAddress(post.address)
    || post.deviceId.length > bc.MAX_DEVICE_ID_LENGTH
  ) {
    result.code = bc.faucetCodes.FAUCET_BAD_REQUEST;
    return result;
  }
  post.deviceId = post.deviceId.trim();
  const record = await Models.airdrop.findOne({
    where: {
      bcId: post.deviceId,
      type: bc.TYPE_AIRDROP,
    },
  });
  if (record) {
    result.code = bc.faucetCodes.FAUCET_DUPLICATE_REQUEST;
    return result;
  }
  await Models.airdrop.create({
    bcId: post.deviceId,
    type: bc.TYPE_AIRDROP,
  });
  console.log('goto blockchain actions...');
  try {
    const currentBalance = await wallet.provider.getBalance(post.address);
    console.error('CURRENT WALLET BALANCE', currentBalance.toString());
    if (
      currentBalance.gt(bc.MIN_BALANCE_TO_AIRDROP)
      || currentBalance.eq(bc.MIN_BALANCE_TO_AIRDROP)
    ) {
      console.error('[current balance is too high, reject airdrop]');
      result.code = bc.faucetCodes.FAUCET_BALANCE_HIGH;
      return result;
    }
    console.log(`SEND ETHER TO ${post.address} [deviceId: ${post.deviceId}]`);
    await wallet.sendTransaction({
      to: post.address,
      value: ethers.utils.parseEther('1'),
    });
  } catch (ex) {
    console.error('[AIRDROP EXCEPTION]', ex);
    result.code = bc.faucetCodes.FAUCET_EXCEPTION;
  }
  return result;
};

export const promoCurrencies = async (post, ip) => {
  console.log('[promoCurrencies]', post);
  const result = {
    code: bc.faucetCodes.FAUCET_SUCCESS,
  };
  if (
    !post.promoCode
    || !post.address
    || !post.deviceId
    || !post.deviceId.trim()
    || !checkAddress(post.address)
    || post.deviceId.length > bc.MAX_DEVICE_ID_LENGTH
  ) {
    result.code = bc.faucetCodes.PROMO_BAD_REQUEST;
    return result;
  }
  if (
    ![
      bc.promo.PROMO_CODE,
      bc.promo.PROMO_CODE_50,
    ].includes(post.promoCode)) {
    console.log(post.promoCode, 'POST CHECK [PROMO_BAD_CODE]');
    result.code = bc.faucetCodes.PROMO_BAD_CODE;
    return result;
  }
  post.deviceId = post.deviceId.trim();
  if (bc.promo.PROMO_CODE_50 !== post.promoCode) {
    const record = await Models.airdrop.findOne({
      where: {
        bcId: post.deviceId,
        type: bc.TYPE_PROMO,
      },
    });
    if (record) {
      result.code = bc.faucetCodes.FAUCET_DUPLICATE_REQUEST;
      return result;
    }
    await Models.airdrop.create({
      bcId: post.deviceId,
      type: bc.TYPE_PROMO,
    });
  }
  console.log('goto blockchain actions...');
  try {
    const balance = await wallet.getBalance();
    console.log('SERVER WALLET BALANCE', balance.toString());
    createContractCurrency(rootWallet, {
      id: 'usd',
      contractAddress: bc.promo.CONTRACT_CURRENCY.usd,
    });
    // console.log('mintResult usd', wallet.usd, 'post.address', post.address, 'amount', ethers.utils.parseEther(post.promoCode === bc.promo.PROMO_CODE ? '10' : '50').toString());
    let mintResult = await rootWallet.usd.mint(post.address, ethers.utils.parseEther(
      post.promoCode === bc.promo.PROMO_CODE ? '10' : '50'
    ));
    console.log(ip, 'mintResult usd', mintResult);
    createContractCurrency(rootWallet, {
      id: 'eur',
      contractAddress: bc.promo.CONTRACT_CURRENCY.eur,
    });
    mintResult = await rootWallet.eur.mint(post.address, ethers.utils.parseEther(
      post.promoCode === bc.promo.PROMO_CODE ? '10' : '50'
    ));
    console.log(ip, 'mintResult eur', mintResult);
    createContractCurrency(rootWallet, {
      id: 'rub',
      contractAddress: bc.promo.CONTRACT_CURRENCY.rub,
    });
    mintResult = await rootWallet.rub.mint(post.address, ethers.utils.parseEther(
      post.promoCode === bc.promo.PROMO_CODE ? '1000' : '5000'
    ));
    console.log(ip, 'mintResult rub', mintResult);

    // should wait mained tx
    // const newBalance = await wallet.contractCurrency.balanceOf( post.address );
    // log('newBalance', newBalance.toString());

    console.log(ip, `PROMO USD SUCCESSFULLY MINTED TO ${post.address} [deviceId: ${post.deviceId}]`);
  } catch (ex) {
    console.error('[AIRDROP EXCEPTION]', ex);
    result.code = bc.faucetCodes.FAUCET_EXCEPTION;
  }
  return result;
};
