import Sequelize from 'sequelize';
import * as constants from '../common/constants';

const { Op } = Sequelize;

const apiKey = (sequelize, DataTypes) => {
  const ApiKey = sequelize.define('apiKeys', {
    state: {
      type: DataTypes.INTEGER,
      allowNull: false,
      validate: {
        notEmpty: true,
      },
    },
    type: {
      type: DataTypes.INTEGER,
      allowNull: false,
      validate: {
        notEmpty: true,
      },
    },
    uuid: {
      type: DataTypes.UUID,
      unique: true,
      allowNull: false,
      validate: {
        notEmpty: true,
      },
    },
    expired: {
      type: DataTypes.DATE,
      false: true,
      allowNull: false,
      validate: {
        notEmpty: true,
      },
    },
    actionsLeft: {
      type: DataTypes.INTEGER,
      allowNull: false,
      validate: {
        notEmpty: true,
      },
    },
    serviceId: {
      type: DataTypes.INTEGER,
      allowNull: false,
      validate: {
        notEmpty: true,
      },
    },
  },
  {
    indexes: [
      {
        fields: ['uuid'],
      },
    ],
  });

  ApiKey.associate = models => {
    ApiKey.belongsTo(models.User);
    ApiKey.belongsTo(models.Group);
  };

  ApiKey.findById = id => {
    return ApiKey.findOne({
      where: { id },
    });
  };

  ApiKey.findByUUID = uuid => {
    return ApiKey.findOne({
      where: { uuid },
    });
  };

  ApiKey.findByUserId = userId => {
    return ApiKey.findAll({
      where: { userId },
    });
  };

  ApiKey.findByUserIdActive = userId => {
    return ApiKey.findAll({
      where: {
        userId,
        state: {
          [Op.ne]: constants.KEY_STATE_DEACTIVATED,
        },
      },
    });
  };

  ApiKey.getUserId = uuid => {
    return ApiKey.findOne({
      where: { uuid },
      state: {
        [Op.ne]: constants.KEY_STATE_DEACTIVATED,
      },
    });
  };

  ApiKey.isActive = key => {
    return key.state === constants.KEY_STATE_ACTIVE;
  };

  return ApiKey;
};

export default apiKey;
