import * as constants from '../common/constants';

const authProject = (sequelize, DataTypes) => {
  const AuthProject = sequelize.define('authProjects', {
    isActive: {
      type: DataTypes.BOOLEAN,
      unique: false,
      allowNull: false,
      validate: {
        notEmpty: true,
      },
    },
    name: {
      type: DataTypes.STRING,
      unique: false,
      allowNull: false,
      validate: {
        notEmpty: true,
        len: [constants.AUTH_PROJECT_NAME_MIN_LENGTH, constants.AUTH_PROJECT_NAME_MAX_LENGTH],
      },
    },
    secretKey: {
      type: DataTypes.STRING,
      unique: false,
      allowNull: false,
      length: constants.AUTH_SECRET_LENGTH,
      validate: {
        notEmpty: true,
        len: constants.AUTH_SECRET_LENGTH,
      },
    },
    apiKeyId: {
      type: DataTypes.INTEGER,
      unique: false,
      allowNull: true,
    },
    uuid: {
      type: DataTypes.UUID,
      unique: true,
      allowNull: false,
    },
  },
  {
    indexes: [
      {
        fields: ['uuid'],
      },
    ],
    freezeTableName: true,
  });

  AuthProject.associate = models => {
    AuthProject.belongsTo(models.User);
    // AuthProject.hasOne(models.ApiKey);
  };

  AuthProject.findByOwnerId = userId => {
    return AuthProject.findAll({
      where: {
        userId,
        isActive: true,
      },
      order: [
        ['createdAt', 'ASC'],
      ],
    });
  };

  AuthProject.findById = id => {
    return AuthProject.findOne({
      where: { id },
    });
  };

  AuthProject.findByUuid = uuid => {
    return AuthProject.findOne({
      where: { uuid },
    });
  };

  AuthProject.checkBelongsToUser = async (userId, groupId) => {
    const count = await AuthProject.findAll({
      where: {
        id: groupId,
        userId,
      },
    });
    return !!count;
  };

  return AuthProject;
};

export default authProject;
