import Sequelize from 'sequelize';

let sequelize;
if (process.env.DATABASE_URL) {
  sequelize = new Sequelize(process.env.DATABASE_URL, {
    dialect: 'postgres',
  });
} else {
  sequelize = new Sequelize(
    process.env.TEST_DATABASE || process.env.DATABASE,
    process.env.DATABASE_USER,
    process.env.DATABASE_PASSWORD,
    {
      dialect: 'postgres',
    }
  );
}

const models = {
  User: sequelize.import('./user'),
  Person: sequelize.import('./person'),
  Group: sequelize.import('./userGroups'),
  GroupMembers: sequelize.import('./groupMembers'),
  GuestAction: sequelize.import('./guestAction'),
  JoinRequest: sequelize.import('./joinRequest'),
  ApiKey: sequelize.import('./apiKeys'),
  Liveness: sequelize.import('./serviceLiveness'),
  FaceAction: sequelize.import('./serviceFaceAction'),
  Documents: sequelize.import('./serviceDocuments'),
  LiveFaceAction: sequelize.import('./serviceLiveFaceAction'),
  Recognition: sequelize.import('./recognition'),
  AuthProject: sequelize.import('./authProjects'),
  AuthBioLink: sequelize.import('./authBioLink'),
  BcAuthSecret: sequelize.import('./bcAuthSecret'),
  airdrop: sequelize.import('./airdrop'),
  'sequelize': sequelize,
};

Object.keys(models).forEach(key => {
  if ('associate' in models[key]) {
    models[key].associate(models);
  }
});

export { sequelize };
export default models;
