import Sequelize from 'sequelize';

const { Op } = Sequelize;

const person = (sequelize, DataTypes) => {
  const Person = sequelize.define('persons', {
    uuid: {
      type: DataTypes.UUID,
      unique: false,
      allowNull: false,
      validate: {
        notEmpty: true,
      },
    },
    bcId: {
      type: DataTypes.STRING,
      // unique: true,
      allowNull: true,
    },
    passCode: {
      type: DataTypes.STRING,
      unique: false,
      allowNull: true,
    },
  },
  {
    indexes: [
      {
        fields: ['uuid'],
      },
      // {
      //   fields: ['bcId'],
      // },
      {
        unique: true,
        fields: ['uuid', 'userId', 'groupId'],
      },
      {
        unique: true,
        fields: ['userId', 'groupId', 'bcId'],
      },
      {
        fields: ['sourceId'],
      },
    ],
    freezeTableName: true,
  });

  Person.associate = models => {
    Person.belongsTo(models.User, { foreignKey: { name: 'userId', allowNull: false } });
    Person.belongsTo(models.ApiKey, { foreignKey: { name: 'sourceId', allowNull: true } });
    Person.belongsTo(models.Group, { foreignKey: { name: 'groupId', allowNull: true } });
  };

  Person.getLastChangedRecord = async id => {
    return Person.findOne({
      where: {
        userId: id,
        sourceId: null,
      },
      order: [
        ['updatedAt', 'DESC'],
      ],
    });
  };

  Person.findWithParams = async where => {
    return Person.findOne({ where });
  };

  Person.findByUUID = async uuid => {
    return Person.findOne({
      where: { uuid },
    });
  };

  Person.findByGroupIds = async ({ groupIds }) => {
    return Person.findAll({
      where: {
        groupId: {
          [Op.in]: groupIds,
        },
      },
      order: [
        ['createdAt', 'DESC'],
      ],
    });
  };

  return Person;
};

export default person;
