import Sequelize from 'sequelize';

const { Op } = Sequelize;

const serviceFaceAction = (sequelize, DataTypes) => {
  const FaceAction = sequelize.define('faceActions', {
    apiKeyId: {
      type: DataTypes.INTEGER,
      unique: false,
      allowNull: false,
      validate: {
        notEmpty: true,
      },
    },
    sessionId: {
      type: DataTypes.UUID,
      unique: true,
      allowNull: false,
      validate: {
        notEmpty: true,
      },
    },
    groupId: {
      type: DataTypes.INTEGER,
      unique: false,
      allowNull: false,
    },
    result: {
      type: DataTypes.FLOAT,
      allowNull: true,
    },
    time: {
      type: DataTypes.FLOAT,
      allowNull: true,
    },
    version: {
      type: DataTypes.FLOAT,
      allowNull: false,
      validate: {
        notEmpty: true,
      },
    },
  });

  FaceAction.associate = models => {
    FaceAction.belongsTo(models.ApiKey);
    FaceAction.belongsTo(models.Group);
    FaceAction.belongsTo(models.User);
    FaceAction.belongsTo(models.Person);
  };

  FaceAction.findById = async id => {
    return FaceAction.findOne({
      where: { id },
    });
  };

  FaceAction.findByGroupAndUserId = async ({ groupId, userId }) => {
    const where = {
      groupId,
    };
    userId && (where.userId = userId);
    return FaceAction.findAll({
      where,
      order: [
        ['createdAt', 'DESC'],
      ],
    });
  };

  FaceAction.findByGroupIds = async ({ groupIds }) => {
    return FaceAction.findAll({
      where: {
        groupId: {
          [Op.in]: groupIds,
        },
      },
      order: [
        ['createdAt', 'DESC'],
      ],
    });
  };

  return FaceAction;
};

export default serviceFaceAction;
