import Sequelize from 'sequelize';

const { Op } = Sequelize;

const serviceLiveFaceAction = (sequelize, DataTypes) => {
  const LiveFaceAction = sequelize.define('liveFaceActions', {
    apiKeyId: {
      type: DataTypes.INTEGER,
      unique: false,
      allowNull: false,
      validate: {
        notEmpty: true,
      },
    },
    sessionId: {
      type: DataTypes.UUID,
      unique: true,
      allowNull: false,
      validate: {
        notEmpty: true,
      },
    },
    groupId: {
      type: DataTypes.INTEGER,
      unique: false,
      allowNull: false,
    },
    resultFace: {
      type: DataTypes.FLOAT,
      allowNull: true,
    },
    resultLive: {
      type: DataTypes.FLOAT,
      allowNull: true,
    },
    timeFace: {
      type: DataTypes.FLOAT,
      allowNull: true,
    },
    timeLive: {
      type: DataTypes.FLOAT,
      allowNull: true,
    },
    versionLive: {
      type: DataTypes.FLOAT,
      allowNull: false,
      validate: {
        notEmpty: true,
      },
    },
    versionFace: {
      type: DataTypes.FLOAT,
      allowNull: false,
      validate: {
        notEmpty: true,
      },
    },
  });

  LiveFaceAction.associate = models => {
    LiveFaceAction.belongsTo(models.ApiKey);
    LiveFaceAction.belongsTo(models.Group);
    LiveFaceAction.belongsTo(models.User);
    LiveFaceAction.belongsTo(models.Person);
  };

  LiveFaceAction.findById = async id => {
    return LiveFaceAction.findOne({
      where: { id },
    });
  };

  LiveFaceAction.findByGroupAndUserId = async ({ groupId, userId }) => {
    const where = {
      groupId,
    };
    userId && (where.userId = userId);
    return LiveFaceAction.findAll({
      where,
      order: [
        ['createdAt', 'DESC'],
      ],
    });
  };

  LiveFaceAction.findByGroupIds = async ({ groupIds }) => {
    return LiveFaceAction.findAll({
      where: {
        groupId: {
          [Op.in]: groupIds,
        },
      },
      order: [
        ['createdAt', 'DESC'],
      ],
    });
  };

  return LiveFaceAction;
};

export default serviceLiveFaceAction;
