import Sequelize from 'sequelize';

const { Op } = Sequelize;

const serviceLiveness = (sequelize, DataTypes) => {
  const Liveness = sequelize.define('liveness', {
    apiKeyId: {
      type: DataTypes.INTEGER,
      unique: false,
      allowNull: false,
      validate: {
        notEmpty: true,
      },
    },
    sessionId: {
      type: DataTypes.UUID,
      unique: true,
      allowNull: false,
      validate: {
        notEmpty: true,
      },
    },
    groupId: {
      type: DataTypes.INTEGER,
      unique: false,
      allowNull: false,
    },
    result: {
      type: DataTypes.FLOAT,
      allowNull: true,
    },
    time: {
      type: DataTypes.FLOAT,
      allowNull: true,
    },
    version: {
      type: DataTypes.FLOAT,
      allowNull: false,
      validate: {
        notEmpty: true,
      },
    },
  },
  {
    freezeTableName: true,
  });

  Liveness.associate = models => {
    Liveness.belongsTo(models.ApiKey);
    Liveness.belongsTo(models.Group);
    Liveness.belongsTo(models.User);
  };

  Liveness.findById = async id => {
    return Liveness.findOne({
      where: { id },
    });
  };

  Liveness.findByGroupAndUserId = async ({ groupId, userId }) => {
    const where = {
      groupId,
    };
    userId && (where.userId = userId);
    return Liveness.findAll({
      where,
      order: [
        ['createdAt', 'DESC'],
      ],
    });
  };

  Liveness.findByGroupIds = async ({ groupIds }) => {
    return Liveness.findAll({
      where: {
        groupId: {
          [Op.in]: groupIds,
        },
      },
      order: [
        ['createdAt', 'DESC'],
      ],
    });
  };

  return Liveness;
};

export default serviceLiveness;
