import bcrypt from 'bcrypt';
import * as constants from '../common/constants';

const user = (sequelize, DataTypes) => {
  const User = sequelize.define('user', {
    isActive: {
      type: DataTypes.BOOLEAN,
      allowNull: false,
      defaultValue: true,
    },
    username: {
      type: DataTypes.STRING,
      allowNull: false,
      validate: {
        notEmpty: true,
      },
    },
    email: {
      type: DataTypes.STRING,
      unique: true,
      allowNull: false,
      validate: {
        notEmpty: true,
        isEmail: true,
      },
    },
    password: {
      type: DataTypes.STRING,
      allowNull: false,
      validate: {
        notEmpty: true,
        len: [constants.PASSWORD_MIN_LENGTH, constants.PASSWORD_MAX_LENGTH],
      },
    },
    role: {
      type: DataTypes.INTEGER,
    },
    biometricSignIn: {
      type: DataTypes.BOOLEAN,
      allowNull: false,
      defaultValue: false,
    },
    uuid: {
      type: DataTypes.UUID,
      unique: true,
      allowNull: false,
      validate: {
        notEmpty: true,
      },
    },
  });

  User.associate = models => {
    User.hasMany(models.Group);
    User.hasMany(models.ApiKey);
  };

  User.findByLogin = async login => {
    let userData = await User.findOne({
      where: { username: login },
    });
    if (!userData) {
      userData = await User.findOne({
        where: { email: login },
      });
    }
    return userData;
  };

  User.findById = id => {
    return User.findOne({
      where: { id },
    });
  };

  User.beforeCreate(async item => {
    item.password = await item.generatePasswordHash();
  });

  User.prototype.generatePasswordHash = function () {
    const saltRounds = 10;
    return bcrypt.hash(this.password, saltRounds);
  };

  User.prototype.validatePassword = function (password) {
    return bcrypt.compare(password, this.password);
  };

  return User;
};

export default user;
