import * as constants from '../common/constants';

const group = (sequelize, DataTypes) => {
  const Group = sequelize.define('groups', {
    isActive: {
      type: DataTypes.BOOLEAN,
      unique: false,
      allowNull: false,
      validate: {
        notEmpty: true,
      },
    },
    name: {
      type: DataTypes.STRING,
      unique: false,
      allowNull: false,
      validate: {
        notEmpty: true,
        len: [constants.GROUP_NAME_MIN_LENGTH, constants.GROUP_NAME_MAX_LENGTH],
      },
    },
  });

  Group.associate = models => {
    Group.belongsTo(models.User);
    Group.hasMany(models.ApiKey);
  };

  Group.findByOwnerId = userId => {
    return Group.findAll({
      where: {
        userId,
        isActive: true,
      },
      order: [
        ['createdAt', 'ASC'],
      ],
    });
  };

  Group.findByOwnerIdFirst = userId => {
    return Group.findOne({
      where: {
        userId,
      },
      order: [
        ['createdAt', 'ASC'],
      ],
      limit: 1,
    });
  };

  Group.findById = id => {
    return Group.findOne({
      where: { id },
    });
  };

  Group.checkGroupBelongsToUser = async (userId, groupId) => {
    const count = await Group.findAll({
      where: {
        id: groupId,
        userId,
      },
    });
    return !!count;
  };

  return Group;
};

export default group;
