import { ForbiddenError } from 'apollo-server';
import { combineResolvers, skip } from 'graphql-resolvers';
import * as constants from '../common/constants';

export const isAuthenticated = (parent, args, { me }) => (me ? skip : new ForbiddenError('Not authenticated as user.'));

export const isAdminUser = me => {
  return me
    ? [
      constants.USER_ROLE_ADMIN,
      constants.USER_ROLE_GOD,
    ].includes(me.role)
    : false;
};

export const isGodUser = me => {
  return me
    ? me.role === constants.USER_ROLE_GOD
    : false;
};

export const isAdmin = combineResolvers(
  isAuthenticated,
  (parent, args, { me }) => (isAdminUser(me)
    ? skip
    : new ForbiddenError('Not authorized as admin.'))
);

export const isGod = combineResolvers(
  isAuthenticated,
  (parent, args, { me }) => (isGodUser(me)
    ? skip
    : new ForbiddenError('Not authorized as God.'))
);
