import { gql } from 'apollo-server-express';

export default gql`
  extend type Query {
    authProject(id: ID!): AuthProject
    authProjects: [AuthProject]!
  }

  extend type Mutation {
    createAuthProject : AuthProject!

    updateAuthProject (
      id: ID!
      isActive: Boolean
      name: String
      apiKeyId: ID
    ): AuthProject!

    authentication (
      files: [Upload!]!
      project: String!
      token: String!
      fields: String!
    ): AuthResult!

    authBlockchain (
      alias: String!
      security: String!
      project: String!
      token: String!
      fields: String!
    ): AuthResult!

    payment (
      alias: String!
      security: String!
      projectId: String!
      productId: String!
      txId: String!
    ): AuthResult!

  }

  type AuthProject {
    id: ID!
    owner: User!
    name: String!
    uuid: String! 
    secretKey: String! 
    apiKey: ApiKey 
    createdAt: Date!
    updatedAt: Date!
  }

  extend type Subscription {
    authProjectCreated: AuthProjectCreated!
  }

  type AuthProjectCreated {
    authProject: AuthProject!
  }

  type AuthResult {
    result: Boolean!
    message: String!
    action: String
  }
`;
