import { gql } from 'apollo-server-express';

export default gql`
  extend type Query {

    faceAction (
      id: ID!
      token: String
    ): FaceAction

    faceActions (
      token: String
      groupId: ID
      cursor: String
      limit: Int
    ): FacesConnection!

  }

  type FacesConnection {
    edges: [FaceAction!]!
    pageInfo: PageInfo!
  }

  extend type Mutation {

    goFace (
      apiKey: String!
      files: [Upload!]!
      version: String
    ): FaceAction

    recognize (
      apiKey: String!
      files: [Upload!]!
      version: String
      pc: String
      npc: String
      bcId: String
      pa: Float
      security: String
    ): FaceAction

  }

  extend type Subscription {

    faceCreated (
      groupId: ID
    ): FaceActionInfo!

    faceUpdated (
      groupId: ID
    ): FaceActionInfo!

  }

  type FaceActionInfo {
    action: FaceAction!
  }

  type FaceAction {
    id: ID!
    imageUrl: String!
    imageUrl200x200: String!
    imageOriginalUrl: String!
    time: Float
    version: String!
    result: Result!
    apiKey: ApiKey!
    group: Group!
    user: User!
    person: Person!
    sessionId: String!
    createdAt: Date!
    updatedAt: Date!
    actionCode: String
  }
`;
