import { gql } from 'apollo-server-express';

export default gql`
  extend type Query {

    liveFaceAction (
      id: ID!
      token: String
    ): LiveFaceAction

    liveFaceActions(
      token: String
      groupId: ID
      cursor: String
      limit: Int
    ): LiveFacesConnection!

  }

  type LiveFacesConnection {
    edges: [LiveFaceAction!]!
    pageInfo: PageInfo!
  }

  extend type Mutation {

    goLiveFace(
      apiKey: String!
      files: [Upload!]!
      versionLive: String
      versionFace: String
    ): LiveFaceAction

    liveFace(
      apiKey: String!
      files: [Upload!]!
      versionLive: String
      versionFace: String
    ): LiveFaceAction

  }

  extend type Subscription {

    liveFaceCreated(
      groupId: ID
    ): LiveFaceActionInfo!

    liveFaceUpdated(
      groupId: ID
    ): LiveFaceActionInfo!

  }

  type LiveFaceActionInfo {
    action: LiveFaceAction!
  }

  type LiveFaceAction {
    id: ID!
    imageUrl: String!
    imageUrl200x200: String!
    imageOriginalUrl: String!
    resultFace: Result!
    resultLive: Result!
    timeFace: Float
    timeLive: Float
    apiKey: ApiKey!
    group: Group!
    user: User!
    person: Person!
    sessionId: String!
    createdAt: Date!
    updatedAt: Date!
  }
`;
