import { gql } from 'apollo-server-express';

export default gql`
  extend type Query {

    livenessItem (
      id: ID!
      token: String
    ): Liveness

    livenessActions (
      token: String
      groupId: ID
      cursor: String
      limit: Int
    ): LivenessConnection!

  }

  type LivenessConnection {
    edges: [Liveness!]!
    pageInfo: PageInfo!
  }

  extend type Mutation {

    goLiveness(
      apiKey: String!
      files: [Upload!]!
      version: String
    ): Liveness

    liveness(
      apiKey: String!
      files: [Upload!]!
      version: String
    ): Liveness

  }

  extend type Subscription {
    livenessCreated(
      groupId: ID
    ): LivenessInfo!

    livenessUpdated(
      groupId: ID
    ): LivenessInfo!
  }

  type LivenessInfo {
    action: Liveness!
  }

  type Liveness {
    id: ID!
    imageUrl: String!
    imageOriginalUrl: String!
    time: Float
    result: Result!
    sessionId: String!
    apiKey: ApiKey!
    group: Group!
    user: User!
    createdAt: Date!
    updatedAt: Date!
  }

  type PageInfo {
    hasNextPage: Boolean!
    endCursor: String!
  }

  type Result {
    success: Boolean
    confidence: String
    error: String!
    score: Float
  }
`;
