import { gql } from 'apollo-server-express';

export default gql`
  extend type Query {
    group(id: ID!): Group
    groups: [Group!]!
    userGroups(id: ID!): [Group!]!
    groupMembers(groupId: ID!): [GroupMember!]!
    groupsByUserId(userId: ID!): [Group!]!
  }

  extend type Mutation {
    createGroup(
      name: String!
    ): Group!

    updateGroup(
      id: ID!
      isActive: Boolean
      name: String
    ): Group!

    joinGroup(
      email: String!
    ): String!

    addMember(
      groupId: ID!
      userId: Int!
      role: Int!
    ): Group!

    removeMember(
      groupId: ID!
      userId: Int!
    ): Group!

    updateMember(
      groupId: ID!
      userId: Int!
      role: Int!
    ): Group!
  }

  type Group {
    id: ID!
    owner: User!
    name: String!
    createdAt: Date!
    updatedAt: Date!
  }

  type GroupMember {
    id: ID!
    user: User!
    role: Int!
    createdAt: Date!
    updatedAt: Date!
  }

  extend type Subscription {
    groupCreated: GroupCreated!
  }

  type GroupCreated {
    group: Group!
  }
`;
